.. rheology_python documentation master file, created by
   sphinx-quickstart on Wed May  1 14:12:06 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to rheofit's documentation
===========================================

Documentation of python rheology library

Initially focused on fitting flow curves to rheological models.

github repository at https://github.com/rheopy/rheofit

Quickstart guide

.. toctree::
   :maxdepth: 1
   :glob:

   Quickstart
   load_data
   Fitting_single_flow_curve
   models


.. toctree::
   :maxdepth: 3
   :glob:

   modules
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
